﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using C1.Silverlight.Pdf;
using System.IO;
using System.IO.IsolatedStorage;
using System.Windows.Media.Imaging;
using System.Reflection;

namespace PdfInvoice
{
    public partial class MainPage : UserControl
    {
        //instantiate c1pdfdocument
        C1PdfDocument _c1Pdf = new C1PdfDocument();

        public MainPage()
        {
            InitializeComponent();
            CreateInvoice();
        }

        private void CreateInvoice()
        {
            Rect _pageRect = _c1Pdf.PageRectangle;
            _pageRect.X = 72;
            _pageRect.Y = 72;

            //page settings
            Font largeFont = new Font("Arial", 36);
            Font mediumFont = new Font("Arial", 18);
            Font smallFont = new Font("Arial", 14);
            int spacing = 20;

            //draw text to pdf
            string text = "Invoice";
            _c1Pdf.DrawString(text, largeFont, Colors.Black, _pageRect);
            Size sz = _c1Pdf.MeasureString(text, largeFont);
            _pageRect.Y += sz.Height + spacing;

            //draw image from resources to PDF
            BitmapImage bi = LoadBitmap("c1ball.jpg");
            var wb = new WriteableBitmap(bi);
            Rect imgRect = new Rect(450, 40, 80, 80);
            _c1Pdf.DrawImage(wb, imgRect);

            //draw line to pdf
            _c1Pdf.DrawLine(new Pen(Colors.Black, 2.0), new Point(72, _pageRect.Y), new Point(504, _pageRect.Y));
            _pageRect.Y += spacing;

            //render order information
            text = "Order #150001";
            _c1Pdf.DrawString(text, mediumFont, Colors.Black, _pageRect);
            sz = _c1Pdf.MeasureString(text, mediumFont);
            _pageRect.Y += sz.Height + spacing;
            text = "Item #301246";
            _pageRect.X = 120;
            _c1Pdf.DrawString(text, smallFont, Colors.Black, _pageRect);
            text = "$0.00";
            _pageRect.X = 450;
            _c1Pdf.DrawString(text, smallFont, Colors.Black, _pageRect);
            sz = _c1Pdf.MeasureString(text, smallFont);
            _pageRect.Y += sz.Height + spacing;
            text = "Item #158824";
            _pageRect.X = 120;
            _c1Pdf.DrawString(text, smallFont, Colors.Black, _pageRect);
            text = "$0.00";
            _pageRect.X = 450;
            _c1Pdf.DrawString(text, smallFont, Colors.Black, _pageRect);
            sz = _c1Pdf.MeasureString(text, smallFont);
            _pageRect.Y += sz.Height + spacing;
            _pageRect.Y += spacing;
            _c1Pdf.DrawLine(new Pen(Colors.Black, 1), new Point(120, _pageRect.Y), new Point(504, _pageRect.Y));
            _pageRect.Y += spacing;
            text = "TOTAL:";
            _pageRect.X = 120;
            _c1Pdf.DrawString(text, smallFont, Colors.Black, _pageRect);
            text = "$0.00";
            _pageRect.X = 450;
            _c1Pdf.DrawString(text, smallFont, Colors.Black, _pageRect);
            sz = _c1Pdf.MeasureString(text, smallFont);
            _pageRect.Y += sz.Height + spacing;

            //Add new page
            _c1Pdf.NewPage();
            _pageRect.Y = 72;
            _pageRect.X = 72;
            _c1Pdf.DrawString("Second Page", smallFont, Colors.Black, _pageRect);
        }

        private void btnPreviewInvoice_Click(object sender, RoutedEventArgs e)
        {
            //save file to isolated storage
            IsolatedStorageFile isf = IsolatedStorageFile.GetUserStoreForApplication();
        
            Stream s = new IsolatedStorageFileStream("MyInvoice.pdf", FileMode.OpenOrCreate, FileAccess.ReadWrite, isf);
            _c1Pdf.Save(s);
            s.Close();
            //open file in c1pdfviewer
            s = isf.OpenFile("MyInvoice.pdf", FileMode.Open);
            c1PdfViewer1.LoadDocument(s);
            s.Close();   
        }

        private void btnSaveInvoice_Click(object sender, RoutedEventArgs e)
        {
            //save file using dialog
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.DefaultExt = ".pdf";
            bool? sfdResult = sfd.ShowDialog();
            if (sfdResult.HasValue && sfdResult.Value)
            {
                using (Stream s = sfd.OpenFile())
                {
                    _c1Pdf.Save(s);
                }
            }
        }
        
        BitmapImage LoadBitmap(string bmpName)
        {
            var bmp = new BitmapImage();
            bmp.SetSource(GetResourceStream(bmpName));
            return bmp;
        }
        Stream GetResourceStream(string resName)
        {
            var asm = Assembly.GetExecutingAssembly();
            foreach (var rn in asm.GetManifestResourceNames())
            {
                if (rn.EndsWith(resName))
                {
                    return asm.GetManifestResourceStream(rn);
                }
            }
            return null;
        }


    }
}
